<?php
/**
 * Filters for theme-related WordPress features. These filters are for handling adding or modifying the
 * output of common WordPress template tags. Many of the filters are simply for adding HTML5 microdata.
 *
 * @package    Hoot Business
 * @subpackage Library
 */

# Add extra support for post types.
add_action( 'init', 'hootbiz_add_post_type_support', 15 );
add_action( 'edit_form_after_title', 'hootbiz_add_page_for_posts_editor', 0 );

# Filters the archive title and description.
add_filter( 'get_the_archive_title',       'hootbiz_archive_title_filter',       5  );
add_filter( 'get_the_archive_description', 'hootbiz_archive_description_filter', 0  );
add_filter( 'get_the_archive_description', 'hootbiz_archive_description_format', 95 );

# Use same default filters as 'the_content' with a little more flexibility.
add_filter( 'hootbiz_archive_description', array( $GLOBALS['wp_embed'], 'run_shortcode' ),   5  );
add_filter( 'hootbiz_archive_description', array( $GLOBALS['wp_embed'], 'autoembed'     ),   5  );
add_filter( 'hootbiz_archive_description',                              'wptexturize',       10 );
add_filter( 'hootbiz_archive_description',                              'convert_smilies',   15 );
add_filter( 'hootbiz_archive_description',                              'convert_chars',     20 );
add_filter( 'hootbiz_archive_description',                              'wpautop',           25 );
add_filter( 'hootbiz_archive_description',                              'do_shortcode',      30 );
add_filter( 'hootbiz_archive_description',                              'shortcode_unautop', 35 );

# Don't strip tags on single post titles.
remove_filter( 'single_post_title', 'strip_tags' );

# Filters the title for untitled posts.
add_filter( 'the_title', 'hootbiz_untitled_post' );

# Default excerpt more.
add_filter( 'the_content_more_link', 'hootbiz_readmore', 5 );
if ( apply_filters( 'hootbiz_force_excerpt_readmore', true ) ) {
	add_filter( 'excerpt_more', 'hootbiz_readmore_quicktag', 6 );
	add_filter( 'wp_trim_excerpt', 'hootbiz_readmore_quicktag_replace', 6, 2 );
} else {
	add_filter( 'excerpt_more', 'hootbiz_readmore', 5 );
}

# Modifies the arguments and output of wp_link_pages().
add_filter( 'wp_link_pages_args', 'hootbiz_link_pages_args', 5 );
add_filter( 'wp_link_pages_link', 'hootbiz_link_pages_link', 5 );

# Filters to add microdata support to common template tags.
add_filter( 'the_author_posts_link',          'hootbiz_the_author_posts_link',          5 );
add_filter( 'get_comment_author_link',        'hootbiz_get_comment_author_link',        5 );
add_filter( 'get_comment_author_url_link',    'hootbiz_get_comment_author_url_link',    5 );
add_filter( 'get_avatar',                     'hootbiz_get_avatar',                     5 );
add_filter( 'post_thumbnail_html',            'hootbiz_post_thumbnail_html',            5 );
add_filter( 'comments_popup_link_attributes', 'hootbiz_comments_popup_link_attributes', 5 );

# Adds custom CSS classes to nav menu items.
add_filter( 'nav_menu_css_class', 'hootbiz_nav_menu_css_class', 5, 2 );

/**
 * This function is for adding extra support for features not default to the core post types.
 * Excerpts are added to the 'page' post type. Comments and trackbacks are added for the
 * 'attachment' post type.  Technically, these are already used for attachments in core, but
 * they're not registered.
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
function hootbiz_add_post_type_support() {

	// Add support for excerpts to the 'page' post type.
	add_post_type_support( 'page', array( 'excerpt' ) );

	// Add thumbnail support for audio and video attachments.
	add_post_type_support( 'attachment:audio', 'thumbnail' );
	add_post_type_support( 'attachment:video', 'thumbnail' );

}

/**
 * This function enables Editor for 'Posts Page'.
 * This content can thus be used as description by hootbiz_archive_description_filter()
 * hooked into 'get_the_archive_description' filter
 *
 * @since 3.0.0
 * @access public
 * @param object $post
 * @return void
 */
function hootbiz_add_page_for_posts_editor( $post ) {

	// Check if this is 'page_for_posts' (blog)
	if ( get_option( 'page_for_posts' ) != $post->ID )
		return;

	remove_action( 'edit_form_after_title', '_wp_posts_page_notice' );
	add_post_type_support( $post->post_type, 'editor' );

}

/**
 * Filters 'get_the_archive_title' to add better archive titles than core.
 *
 * @since 3.0.0
 * @access public
 * @param string $title
 * @return string
 */
function hootbiz_archive_title_filter( $title ) {

	if ( is_home() && ! is_front_page() )
		$title = get_post_field( 'post_title', get_queried_object_id() );

	elseif ( is_category() || is_tag() )
		$title = get_the_archive_title();

	elseif ( is_tax() )
		$title = single_term_title( '', false );

	elseif ( is_author() )
		$title = hootbiz_get_single_author_title();

	elseif ( is_search() )
		$title = hootbiz_get_search_title();

	elseif ( is_post_type_archive() )
		$title = post_type_archive_title( '', false );

	elseif ( is_month() )
		$title = single_month_title( ' ', false );

	elseif ( is_year() )
		$title = hootbiz_get_single_year_title();

	elseif ( is_archive() )
		$title = hootbiz_get_single_archive_title();

	/* If the current page is a paged page. */
	if ( ( ( $page = get_query_var( 'paged' ) ) || ( $page = get_query_var( 'page' ) ) ) && $page > 1 ) {
		$paged = number_format_i18n( absint( $page ) );
		/* Translators: %s is page number */
		$suffix = ' <span class="loop-title-suffix">' . sprintf( __( '(Page %s)', 'hoot-business' ), $paged ) . '</span>';
		$suffix = apply_filters( 'hootbiz_archive_title_paged', $suffix, $paged );
		$title .= $suffix;
	}

	return apply_filters( 'hootbiz_archive_title', $title );
}

/**
 * Filters 'get_the_archve_description' to add better archive descriptions than core.
 *
 * @since 3.0.0
 * @access public
 * @param string $desc
 * @return string
 */
function hootbiz_archive_description_filter( $desc ) {

	if ( is_home() && ! is_front_page() )
		$desc = get_post_field( 'post_content', get_queried_object_id(), 'raw' );

	elseif ( is_category() )
		$desc = get_term_field( 'description', get_queried_object_id(), 'category', 'raw' );

	elseif ( is_tag() )
		$desc = get_term_field( 'description', get_queried_object_id(), 'post_tag', 'raw' );

	elseif ( is_tax() )
		$desc = get_term_field( 'description', get_queried_object_id(), get_query_var( 'taxonomy' ), 'raw' );

	elseif ( is_author() )
		$desc = get_the_author_meta( 'description', get_query_var( 'author' ) );

	elseif ( is_post_type_archive() )
		$desc = get_post_type_object( get_query_var( 'post_type' ) )->description;

	elseif ( is_search() ) {
		$search_query = get_search_query();
		/* Translators: %s is user search query */
		$desc = sprintf( __( 'You are browsing the search results for &#8220;%s&#8221;', 'hoot-business' ), $search_query );
		$desc = apply_filters( 'hootbiz_search_description', $desc, $search_query );
	}

	elseif ( is_time() ) // hour, minute
		$desc = __( 'You are browsing the site archives by time.', 'hoot-business' );

	elseif ( is_month() )
		/* Translators: %s is month name */
		$desc = sprintf( __( 'You are browsing the site archives for %s.', 'hoot-business' ), single_month_title( ' ', false ) );

	elseif ( is_year() )
		/* Translators: %s is year title */
		$desc = sprintf( __( 'You are browsing the site archives for %s.', 'hoot-business' ), hootbiz_get_single_year_title() );

	elseif ( is_archive() )
		$desc = __( 'You are browsing the site archives.', 'hoot-business' );

	return $desc;
}

/**
 * Filters 'get_the_archve_description' to add custom formatting.
 *
 * @since 3.0.0
 * @access public
 * @param string $desc
 * @return string
 */
function hootbiz_archive_description_format( $desc ) {
	return apply_filters( 'hootbiz_archive_description', wp_kses_post( $desc ) );
}

/**
 * The WordPress.org theme review requires that a link be provided to the single post page for untitled
 * posts. This is a filter on 'the_title' so that an '(Untitled)' title appears in that scenario, allowing
 * for the normal method to work.
 *
 * @since 3.0.0
 * @access public
 * @param string $title
 * @return string
 */
function hootbiz_untitled_post( $title ) {
	// Translators: Used as a placeholder for untitled posts on non-singular views.
	if ( ! $title && ! is_singular() && in_the_loop() && ! is_admin() )
		$title = esc_html__( '(Untitled)', 'hoot-business' );

	return $title;
}

/**
 * Filters the excerpt more output with internationalized text and a link to the post.
 *
 * @since 3.0.0
 * @access public
 * @param string $more
 * @return string
 */
function hootbiz_readmore( $more = '[&hellip;]' ) {
	if ( is_admin() )
		return $more;

	$read_more = apply_filters( 'hootbiz_readmoretext', $more );
	global $post;
	$read_more = '<span class="more-link"><a href="' . esc_url( get_permalink( $post->ID ) ) . '">' . esc_html( $read_more ) . '</a></span>';

	return wp_kses_post( apply_filters( 'hootbiz_readmore', $read_more ) );
}

/**
 * Always display the 'Read More' link in Excerpts (even when excerpt is actually smaller than excerpt length)
 * Insert quicktag to be replaced later in 'wp_trim_excerpt()'
 *
 * @since 3.0.0
 * @access public
 * @param string $more
 * @return string
 */
function hootbiz_readmore_quicktag( $more = '' ) {
	if ( is_admin() )
		return $more;
	return '<!--hootbiz-read-more-quicktag-->';
}

/**
 * Always display the 'Read More' link in Excerpts (even when excerpt is actually smaller than excerpt length)
 * Replace quicktag with read more link
 *
 * @since 3.0.0
 * @access public
 * @param string $text
 * @param string $raw_excerpt
 * @return string
 */
function hootbiz_readmore_quicktag_replace( $text, $raw_excerpt ) {
	if ( is_admin() )
		return $text;
	$read_more = hootbiz_readmore();
	return str_replace( '<!--hootbiz-read-more-quicktag-->', $read_more, $text );
}

/**
 * Wraps the output of 'wp_link_pages()' with '<p class="page-links">' if it's simply wrapped in a
 * '<p>' tag.
 *
 * @since 3.0.0
 * @access public
 * @param array $args
 * @return array
 */
function hootbiz_link_pages_args( $args ) {
	$args['before'] = str_replace( '<p>', '<p class="page-links">', $args['before'] );
	return $args;
}

/**
 * Wraps page "links" that aren't actually links (just text) with '<span class="page-numbers">' so that they
 * can also be styled. This makes 'wp_link_pages()' consistent with the output of 'paginate_links()'.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @return string
 */
function hootbiz_link_pages_link( $link ) {
	return 0 !== strpos( $link, '<a' ) ? "<span class='page-numbers'>{$link}</span>" : $link;
}

/**
 * Adds microdata to the author posts link.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @return string
 */
function hootbiz_the_author_posts_link( $link ) {

	$pattern = array(
		"/(<a.*?)(>)/i",
		'/(<a.*?>)(.*?)(<\/a>)/i'
	);

	$replace = array(
		'$1 class="url fn n" itemprop="url"$2',
		'$1<span itemprop="name">$2</span>$3'
	);

	return preg_replace( $pattern, $replace, $link );
}

/**
 * Adds microdata to the comment author link.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @return string
 */
function hootbiz_get_comment_author_link( $link ) {

	$pattern = array(
		'/(class=[\'"])(.+?)([\'"])/i',
		"/(<a.*?)(>)/i",
		'/(<a.*?>)(.*?)(<\/a>)/i'
	);

	$replace = array(
		'$1$2 fn n$3',
		'$1 itemprop="url"$2',
		'$1<span itemprop="name">$2</span>$3'
	);

	return preg_replace( $pattern, $replace, $link );
}

/**
 * Adds microdata to the comment author URL link.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @return string
 */
function hootbiz_get_comment_author_url_link( $link ) {

	$pattern = array(
		'/(class=[\'"])(.+?)([\'"])/i',
		"/(<a.*?)(>)/i"
	);
	$replace = array(
		'$1$2 fn n$3',
		'$1 itemprop="url"$2'
	);

	return preg_replace( $pattern, $replace, $link );
}

/**
 * Adds microdata to avatars.
 *
 * @since 3.0.0
 * @access public
 * @param string $avatar
 * @return string
 */
function hootbiz_get_avatar( $avatar ) {
	return preg_replace( '/(<img.*?)(\/>)/i', '$1itemprop="image" $2', $avatar );
}

/**
 * Adds microdata to the post thumbnail HTML.
 *
 * @since 3.0.0
 * @access public
 * @param string $html
 * @return string
 */
function hootbiz_post_thumbnail_html( $html ) {
	return function_exists( 'get_the_image' ) ? $html : preg_replace( '/(<img.*?)(\/>)/i', '$1itemprop="image" $2', $html );
}

/**
 * Adds microdata to the comments popup link.
 *
 * @since 3.0.0
 * @access public
 * @param string $attr
 * @return string
 */
function hootbiz_comments_popup_link_attributes( $attr ) {
	return 'itemprop="discussionURL"';
}

/**
 * Adds a custom class to nav menu items that correspond to a post type archive.  The
 * 'menu-item-parent-archive' class is shown when viewing a single post of that belongs
 * to the given post type.
 *
 * @since 3.0.0
 * @access public
 * @param array $classes
 * @param object $item
 * @return array
 */
function hootbiz_nav_menu_css_class( $classes, $item ) {
	if ( 'post_type' === $item->type && is_singular( $item->object ) )
		$classes[] = 'menu-item-parent-archive';
	return $classes;
}