<?php
/**
 * Functions for outputting common site data in the '<head>' area of a site.
 *
 * @package    Hoot Business
 * @subpackage Library
 */

# Adds common theme items to <head>.
add_action( 'wp_head', 'hootbiz_meta_charset', 0 );
add_action( 'wp_head', 'hootbiz_meta_viewport', 1 );
add_action( 'wp_head', 'hootbiz_meta_generator', 1 );
add_action( 'wp_head', 'hootbiz_link_pingback', 3 );

# Filter the WordPress title.
add_filter( 'document_title_parts', 'hootbiz_document_title_parts', 5 );

/**
 * Adds the meta charset to the header.
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
function hootbiz_meta_charset() {
	printf( '<meta charset="%s" />' . "\n", esc_attr( get_bloginfo( 'charset' ) ) );
}

/**
 * Adds the meta viewport to the header.
 *
 * @since 3.0.0
 * @access public
 */
function hootbiz_meta_viewport() {
	echo '<meta name="viewport" content="width=device-width, initial-scale=1" />' . "\n";
}

/**
 * Adds the theme generator meta tag. This is particularly useful for checking theme users version
 * when handling support requests.
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
function hootbiz_meta_generator() {
	$generator = sprintf( '<meta name="generator" content="%s %s" />' . "\n", esc_attr( hootbiz_data()->template_name ), esc_attr( hootbiz_data()->template_version ) );
	echo wp_kses( apply_filters( 'hootbiz_meta_generator', $generator ), hootbiz_data( 'hootallowedtags' ) );
}

/**
 * Adds the pingback link to the header.
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
function hootbiz_link_pingback() {
	if ( 'open' === get_option( 'default_ping_status' ) )
		printf( '<link rel="pingback" href="%s" />' . "\n", esc_url( get_bloginfo( 'pingback_url' ) ) );
}

/**
 * Replacement for the older filter on 'wp_title' since WP has moved to a new document
 * title system.  This new filter merely alters the 'title' key based on the current
 * page being viewed.  It also makes sure that all tags are stripped, which WP doesn't
 * do by default (it escapes HTML).
 *
 * @since 3.0.0
 * @access public
 * @param array $doctitle
 * @return array
 */
function hootbiz_document_title_parts( $doctitle ) {

	if ( is_front_page() )
		$doctitle['title'] = get_bloginfo( 'name', 'display' );

	elseif ( is_home() || is_singular() )
		$doctitle['title'] = single_post_title( '', false );

	elseif ( is_category() || is_tag() || is_tax() )
		$doctitle['title'] = single_term_title( '', false );

	elseif ( is_post_type_archive() )
		$doctitle['title'] = post_type_archive_title( '', false );

	elseif ( is_author() )
		$doctitle['title'] = hootbiz_get_single_author_title();

	elseif ( is_month() )
		$doctitle['title'] = single_month_title( '', false );

	elseif ( is_year() )
		$doctitle['title'] = hootbiz_get_single_year_title();

	elseif ( is_archive() )
		$doctitle['title'] = hootbiz_get_single_archive_title();

	elseif ( is_search() )
		$doctitle['title'] = hootbiz_get_search_title();

	elseif ( is_404() || hootbiz_is_404() )
		$doctitle['title'] = hootbiz_get_404_title();

	// Return the title and make sure to strip tags.
	return array_map( 'strip_tags', $doctitle );
}