<?php
/**
 * General template functions. These functions are for use throughout the theme's various template files.
 * Their main purpose is to handle many of the template tags that are currently lacking in core WordPress.
 *
 * @credit https://github.com/justintadlock/hybrid-core/blob/master/inc/template-comments.php
 * @credit https://github.com/justintadlock/hybrid-core/blob/master/inc/template-general.php
 *
 * @package    Hoot Business
 * @subpackage Library
 */

/**
 * Function for checking if 404 page is being displayed.
 * This is an extension to the WordPress 'is_404()' conditional tag, as it checks if the main
 * query is altered to display a custom page as 404 page
 *
 * @since 3.0.0
 * @access public
 * @return bool
 */
function hootbiz_is_404() {
	global $hootbiz_data;
	if ( isset( $hootbiz_data->is_404 ) && is_bool( $hootbiz_data->is_404 ) )
		return $hootbiz_data->is_404;
	else
		return is_404();
}

/**
 * Outputs an HTML element's attributes.
 *
 * @since 3.0.0
 * @access public
 * @param string $slug The slug/ID of the element (e.g., 'sidebar').
 * @param string $context A specific context (e.g., 'primary').
 * @param string|array $attr Addisitonal css classes to add / Array of attributes to pass in (overwrites filters).
 * @return void
 */
function hootbiz_attr( $slug, $context = '', $attr = '' ) {
	echo hootbiz_get_attr( $slug, $context, $attr );
}

/**
 * Gets an HTML element's attributes. This function is actually meant so plugins and child themes can easily filter data.
 * The purpose is to allow modify, remove, or add any attributes without having to edit every template file in the theme.
 * So, one could support microformats instead of microdata, if desired.
 *
 * @since 3.0.0
 * @access public
 * @param string $slug The slug/ID of the element (e.g., 'sidebar').
 * @param string $context A specific context (e.g., 'primary').
 * @param string|array $attr Addisitonal css classes to add / Array of attributes to pass in (overwrites filters).
 * @return string
 */
function hootbiz_get_attr( $slug, $context = '', $attr = '' ) {

	/* Define variables */
	$out = '';
	$customclass = ( !is_array( $attr ) ) ? $attr : '';
	$attr = ( !is_array( $attr ) ) ? array() : $attr;
	$attr['customclass'] = ( !empty( $customclass ) ) ? $customclass : '';

	/* Build attrs */
	// $slugger = str_replace( "-", "_", $slug );
	// $attr    = wp_parse_args( $attr, apply_filters( "hootbiz_attr_{$slugger}", array(), $context, $attr ) );
	$attr = wp_parse_args( $attr, apply_filters( "hootbiz_attr_{$slug}", array(), $context, $attr ) );
	if ( !isset( $attr['class'] ) )
		$attr['class'] = $slug;

	/* Add custom Classes if any */
	if ( !empty( $attr['customclass'] ) && is_string( $attr['customclass'] ) )
		$attr['class'] .= ' ' . $attr['customclass'];
	unset( $attr['customclass'] );

	/* Create attributes */

	// 1. Get ID and class first
	foreach ( array( 'id', 'class' ) as $key ) {
		if ( !empty( $attr[ $key ] ) ) {
			$out .= ' ' . esc_attr( $key ) . '="' . hootbiz_sanitize_html_classes( $attr[ $key ] ) . '"';
			unset( $attr[ $key ] );
		}
	}

	// 2. Remaining attributes
	foreach ( $attr as $name => $value ) {
		if ( $value !== false ) {
			$out .= ( !empty( $value ) ) ?
					' ' . esc_attr( $name ) . '="' . esc_attr( $value ) . '"' :
					' ' . esc_attr( $name );
		}
	}

	return trim( $out );
}

/**
 * Callback function for 'wp_list_comments' to display individual comments
 *
 * @since 3.0.0
 * @access public
 * @param array
 * @param string
 * @return array
 */
if ( !function_exists( 'hootbiz_comments_callback' ) ) :
function hootbiz_comments_callback( $comment ) {

	// Get the comment type of the current comment.
	$comment_type = get_comment_type( $comment->comment_ID );

	// Locate the template and include it
	$template = hootbiz_get_comment( $comment_type, false );
	if ( !empty( $template ) )
		include( $template );

}
endif;

/**
 * Callback function for 'wp_list_comments' to display end of individual comments
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
if ( !function_exists( 'hootbiz_comments_end_callback' ) ) :
function hootbiz_comments_end_callback() {
	echo '</li><!-- .comment -->';
}
endif;

/**
 * Outputs the comment reply link.  Note that WP's 'comment_reply_link()' doesn't work outside of
 * 'wp_list_comments()' without passing in the proper arguments (it isn't meant to).  This function
 * is just a wrapper for 'get_comment_reply_link()', which adds in the arguments automatically.
 *
 * @since 3.0.0
 * @access public
 * @param  array  $args
 * @return string
 */
if ( !function_exists( 'hootbiz_comment_reply_link' ) ) :
function hootbiz_comment_reply_link( $args = array() ) {

	if ( ! get_option( 'thread_comments' ) || in_array( get_comment_type(), array( 'pingback', 'trackback' ) ) )
		return '';

	$args = wp_parse_args(
		$args,
		array(
			'depth'     => intval( $GLOBALS['comment_depth'] ),
			'max_depth' => get_option( 'thread_comments_depth' ),
		)
	);
	echo get_comment_reply_link( $args );

}
endif;

/**
 * Returns a link back to the site.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */

if ( !function_exists( 'hootbiz_get_site_link' ) ) :
function hootbiz_get_site_link() {
	return sprintf( '<a class="site-link" href="%s" rel="home">%s</a>', esc_url( home_url() ), get_bloginfo( 'name' ) );
}
endif;

/**
 * Returns a link to WordPress.org.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */
if ( !function_exists( 'hootbiz_get_wp_link' ) ) :
function hootbiz_get_wp_link() {
	return sprintf( '<a class="wp-link" href="%s">%s</a>', esc_url( __( 'https://wordpress.org', 'hoot-business' ) ), esc_html__( 'WordPress', 'hoot-business' ) );
}
endif;

/**
 * Returns a link to theme on WordPress.org.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @param string $anchor
 * @return string
 */
if ( !function_exists( 'hootbiz_get_wp_theme_link' ) ) :
function hootbiz_get_wp_theme_link( $link = '', $anchor = '' ) {
	$slug   = preg_replace( "/[\s-]+/", " ", strtolower( hootbiz_data()->template_name ) );
	$slug   = str_replace( " ", "-", $slug );
	$link   = ( empty( $link ) ) ? 'https://wordpress.org/themes/' . $slug : $link;
	$anchor = ( empty( $anchor ) ) ? hootbiz_data()->template_name : $anchor;
	/* Translators: %s is the Template Name */
	$title  = sprintf( __( '%s WordPress Theme', 'hoot-business' ), hootbiz_data()->template_name );

	return sprintf( '<a class="wp-theme-link" href="%s" title="%s">%s</a>', esc_url( $link ), esc_attr( $title ), esc_html( $anchor ) );
}
endif;

/**
 * Returns a link to the theme URI.
 *
 * @since 3.0.0
 * @access public
 * @param string $link
 * @param string $anchor
 * @return string
 */
if ( !function_exists( 'hootbiz_get_theme_link' ) ) :
function hootbiz_get_theme_link( $link = '', $anchor = '' ) {
	$link   = ( empty( $link ) ) ? hootbiz_data()->template_author_uri : $link;
	$anchor = ( empty( $anchor ) ) ? hootbiz_data()->template_name : $anchor;
	/* Translators: %s is the Template Name */
	$title  = sprintf( __( '%s WordPress Theme', 'hoot-business' ), hootbiz_data()->template_name );

	return sprintf( '<a class="theme-link" href="%s" title="%s">%s</a>', esc_url( $link ), esc_attr( $title ), esc_html( $anchor ) );
}
endif;

/**
 * Get excerpt with Custom Length
 * This function must be used within loop
 * @NU
 *
 * @since 3.0.0
 * @access public
 * @param int $words
 * @return string
 */
function hootbiz_get_excerpt( $words ) {
	if ( empty( $words ) ) {
		return apply_filters( 'the_excerpt', get_the_excerpt() );
	} else {
		hootbiz_set_data( 'excerpt_customlength', $words );
		add_filter( 'excerpt_length', 'hootbiz_getexcerpt_customlength', 99999 );
		$return = apply_filters( 'the_excerpt', get_the_excerpt() );
		remove_filter( 'excerpt_length', 'hootbiz_getexcerpt_customlength', 99999 );
		hootbiz_unset_data( 'excerpt_customlength' );
		return $return;
	}
}

/**
 * Custom Excerpt Length if set
 * @NU
 *
 * @since 3.0.0
 * @access public
 * @param int $length
 * @return int
 */
function hootbiz_getexcerpt_customlength( $length ){
	$excerpt_customlength = hootbiz_data( 'excerpt_customlength' );
	if ( !empty( $excerpt_customlength ) )
		return $excerpt_customlength;
	else
		return $length;
}

/**
 * Temporarily remove read more links from excerpts
 * Used with 'hootbiz_reinstate_readmore_link'
 * @NU
 *
 * @since 3.0.0
 * @access public
 */
if ( !function_exists( 'hootbiz_remove_readmore_link' ) ):
function hootbiz_remove_readmore_link() {
	add_filter( 'hootbiz_readmore', 'hootbiz_readmore_empty_string' );
}
endif;
if ( !function_exists( 'hootbiz_readmore_empty_string' ) ):
function hootbiz_readmore_empty_string() {
	return '';
}
endif;

/**
 * Reinstate read more links to excerpts
 * Used with 'hootbiz_remove_readmore_link'
 * @NU
 *
 * @since 3.0.0
 * @access public
 */
if ( !function_exists( 'hootbiz_reinstate_readmore_link' ) ):
function hootbiz_reinstate_readmore_link() {
	remove_filter( 'hootbiz_readmore', 'hootbiz_readmore_empty_string' );
}
endif;

/**
 * Retrieve the general archive title.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */
if ( !function_exists( 'hootbiz_get_single_archive_title' ) ) :
function hootbiz_get_single_archive_title() {
	return esc_html__( 'Archives', 'hoot-business' );
}
endif;

/**
 * Retrieve the author archive title.
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
if ( !function_exists( 'hootbiz_get_single_author_title' ) ) :
function hootbiz_get_single_author_title() {
	return get_the_author_meta( 'display_name', absint( get_query_var( 'author' ) ) );
}
endif;

/**
 * Retrieve the year archive title.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */
if ( !function_exists( 'hootbiz_get_single_year_title' ) ) :
function hootbiz_get_single_year_title() {
	return get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'hoot-business' ) );
}
endif;

/**
 * Retrieve the search results title.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */
if ( !function_exists( 'hootbiz_get_search_title' ) ) :
function hootbiz_get_search_title() {
	// Translators: %s is the search query.
	return sprintf( esc_html__( 'Search results for: %s', 'hoot-business' ), get_search_query() );
}
endif;

/**
 * Retrieve the 404 page title.
 *
 * @since 3.0.0
 * @access public
 * @return string
 */
if ( !function_exists( 'hootbiz_get_404_title' ) ) :
function hootbiz_get_404_title() {
	return esc_html__( '404 Not Found', 'hoot-business' );
}
endif;

/**
 * Add debug info if HOOT_DEBUG is true
 *
 * @since 3.0.0
 * @access public
 */
function hootbiz_debug_info( $msg, $return = false ) {
	static $string = '';
	if ( !empty( $msg ) )
		$string = $string . $msg;
	if ( $return )
		return $string;
}

/**
 * Add debug info if HOOT_DEBUG is true
 *
 * @since 3.0.0
 * @access public
 */
function hootbiz_add_debug_info() {
	if ( current_user_can('manage_options') ) {
		echo "\n<!-- HOOT DEBUG INFO-->\n" ;
		if ( function_exists( 'hootbiz_developer_data' ) )
			echo "\n<!-- " . esc_html( hootbiz_developer_data() ) . "-->\n" ;
		$info = ( defined( 'HOOT_DEBUG' ) && true === HOOT_DEBUG ) ? hootbiz_debug_info( '', true ) : '';
		if ( $info )
			echo "<!--\n" . esc_html( $info ) . "\n-->" ;
	}
}
add_action( 'wp_footer', 'hootbiz_add_debug_info' );
add_action( 'admin_footer', 'hootbiz_add_debug_info' );

/**
 * Display Site Performance Data
 *
 * @since 3.0.0
 * @access public
 * @return void
 */
function hootbiz_developer_data( $commented = true ) {
	ob_start();
	echo intval( get_num_queries() ) . ' ' . esc_attr__( 'queries.', 'hoot-business' ) . ' ';
	timer_stop(1);
	echo esc_html( ' ' . __( 'seconds.', 'hoot-business' ) . ' ' . ( memory_get_peak_usage(1) / 1024 ) / 1024 . 'MB' );
	$out = ob_get_contents();
	ob_end_clean();
	return $out;
}